@@ -3,29 +3,23 @@ Evaluation module
 """
 import pandas as pd
 import geopandas as gpd
-from rasterio.plot import show
 import shapely
-from matplotlib import pyplot
 import numpy as np
 
 from deepforest import IoU
 from deepforest.utilities import check_file
-from deepforest import visualize
 
-
-def evaluate_image(predictions, ground_df, show_plot, root_dir, savedir):
+def evaluate_image(predictions, ground_df, root_dir, savedir):
     """
     Compute intersection-over-union matching among prediction and ground truth boxes for one image
     Args:
         df: a pandas dataframe with columns name, xmin, xmax, ymin, ymax, label. The 'name' column should be the path relative to the location of the file.
-        show: Whether to show boxes as they are plotted
         summarize: Whether to group statistics by plot and overall score
         image_coordinates: Whether the current boxes are in coordinate system of the image, e.g. origin (0,0) upper left.
         root_dir: Where to search for image names in df
     Returns:
         result: pandas dataframe with crown ids of prediciton and ground truth and the IoU score.
     """
-
     plot_names = predictions["image_path"].unique()
     if len(plot_names) > 1:
         raise ValueError("More than one plot passed to image crown: {}".format(plot_name))
@@ -40,19 +34,6 @@ def evaluate_image(predictions, ground_df, show_plot, root_dir, savedir):
         lambda x: shapely.geometry.box(x.xmin, x.ymin, x.xmax, x.ymax), axis=1)
     ground_df = gpd.GeoDataFrame(ground_df, geometry='geometry')
 
-    if savedir:
-        visualize.plot_prediction_dataframe(df=predictions,
-                                            ground_truth=ground_df,
-                                            root_dir=root_dir,
-                                            savedir=savedir)
-    else:
-        if show_plot:
-            visualize.plot_prediction_dataframe(df=predictions,
-                                                ground_truth=ground_df,
-                                                root_dir=root_dir,
-                                                savedir=savedir,
-                                                show=True)
-
     # match
     result = IoU.compute_IoU(ground_df, predictions)
     
@@ -66,7 +47,6 @@ def evaluate_image(predictions, ground_df, show_plot, root_dir, savedir):
 def evaluate(predictions,
              ground_df,
              root_dir,
-             show_plot=True,
              iou_threshold=0.4,
              savedir=None):
     """Image annotated crown evaluation routine
@@ -76,7 +56,6 @@ def evaluate(predictions,
         predictions: a pandas dataframe, if supplied a root dir is needed to give the relative path of files in df.name. The labels in ground truth and predictions must match. If one is numeric, the other must be numeric.
         ground_df: a pandas dataframe, if supplied a root dir is needed to give the relative path of files in df.name
         root_dir: location of files in the dataframe 'name' column.
-        show_plot: Whether to show boxes as they are plotted
     Returns:
         results: a dataframe of match bounding boxes
         box_recall: proportion of true positives of box position, regardless of class
@@ -98,7 +77,6 @@ def evaluate(predictions,
         group = group.reset_index(drop=True)
         result = evaluate_image(predictions=group,
                                 ground_df=plot_ground_truth,
-                                show_plot=show_plot,
                                 root_dir=root_dir,
                                 savedir=savedir)
         result["image_path"] = image_path
@@ -127,9 +105,10 @@ def evaluate(predictions,
         class_precision_dict = {}
         class_size = {}
         
-        for name, group in results.groupby("true_label"):
+        box_results =  results[results.predicted_label.notna()]
+        for name, group in box_results.groupby("true_label"):
             class_recall_dict[name] = sum(group.true_label == group.predicted_label)/group.shape[0]
-            number_of_predictions = predictions[predictions.label==name].shape[0]
+            number_of_predictions = group[group.predicted_label==name].shape[0]
             if number_of_predictions == 0:
                 class_precision_dict[name] = 0
             else:
